==> RoughlyEnoughItems-api-5.2.7-sources.jar: me/shedaniel/rei/utils/ImmutableLiteralText.java <==
/*
 * This file is licensed under the MIT License, part of Roughly Enough Items.
 * Copyright (c) 2018, 2019, 2020 shedaniel
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package me.shedaniel.rei.utils;

import net.minecraft.class_2477;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2585;
import net.minecraft.class_5250;
import net.minecraft.class_5481;
import net.minecraft.text.*;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

public final class ImmutableLiteralText implements class_2561 {
    public static final ImmutableLiteralText EMPTY = new ImmutableLiteralText("");
    private final String content;
    private class_5481 orderedText;
    
    public ImmutableLiteralText(String content) {
        this.content = content;
    }
    
    @Override
    public class_2583 method_10866() {
        return class_2583.field_24360;
    }
    
    @Override
    public String method_10851() {
        return content;
    }
    
    @Override
    public List<class_2561> method_10855() {
        return Collections.emptyList();
    }
    
    @Override
    public class_5250 method_27662() {
        return new class_2585(content);
    }
    
    @Override
    public class_5250 method_27661() {
        return method_27662();
    }
    
    @Override
    public <T> Optional<T> method_27657(class_5245<T> visitor) {
        return method_27659(visitor);
    }
    
    @Override
    public <T> Optional<T> method_27658(class_5246<T> styledVisitor, class_2583 style) {
        return method_27660(styledVisitor, style);
    }
    
    @Override
    public class_5481 method_30937() {
        if (orderedText == null) {
            orderedText = class_2477.method_10517().method_30934(this);
        }
        return orderedText;
    }
}

==> RoughlyEnoughItems-api-5.6.2-sources.jar: me/shedaniel/rei/utils/ImmutableLiteralText.java <==
/*
 * This file is licensed under the MIT License, part of Roughly Enough Items.
 * Copyright (c) 2018, 2019, 2020 shedaniel
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package me.shedaniel.rei.utils;

import java.util.Collections;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_2477;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2585;
import net.minecraft.class_5250;
import net.minecraft.class_5481;

public final class ImmutableLiteralText implements class_5250 {
    public static final ImmutableLiteralText EMPTY = new ImmutableLiteralText("");
    private final String content;
    private class_5481 orderedText;
    
    public ImmutableLiteralText(String content) {
        this.content = content;
    }
    
    @Override
    public class_2583 method_10866() {
        return class_2583.field_24360;
    }
    
    @Override
    public String method_10851() {
        return content;
    }
    
    @Override
    public List<class_2561> method_10855() {
        return Collections.emptyList();
    }
    
    @Override
    public class_5250 method_27662() {
        return this;
    }
    
    @Override
    public class_5250 method_27661() {
        return method_27662();
    }
    
    @Override
    public <T> Optional<T> method_27657(class_5245<T> visitor) {
        return method_27659(visitor);
    }
    
    @Override
    public <T> Optional<T> method_27658(class_5246<T> styledVisitor, class_2583 style) {
        return method_27660(styledVisitor, style);
    }
    
    @Override
    public class_5481 method_30937() {
        if (orderedText == null) {
            orderedText = class_2477.method_10517().method_30934(this);
        }
        return orderedText;
    }
    
    @Override
    public class_5250 method_10862(class_2583 style) {
        return new class_2585(content).method_27696(style);
    }
    
    @Override
    public class_5250 method_10852(class_2561 component) {
        return new class_2585(content).method_10852(component);
    }
}
